#!/usr/bin/env python

from coupling import Scharfenberg
from vehicle import Vehicle, Consist


# """It should be noted that Class 373/1 (Three Capitals) and Class 373/2 (Regional)
# trains have different swept envelopes, as a result of the 373/2 vehicle having a
# modified airbag skirt.
# - http://www.rgsonline.co.uk/Railway_Group_Standards/Infrastructure/Guidance%20Notes/GEGN8573%20Iss%202.pdf

# drag coefficient 0.0702-0.0743
# Perimeter 11.24 
# cross-section 8.9 m^2

class Class373(Consist):
    def __init__(self):
        Consist.__init__(self)
    # http://therailwaycentre.com/New%20EMU%20Tech%20Data/EMU_373.html
    class Cl373Vehicle(Vehicle):
        def __init__(self,*args,**kwargs):
            Vehicle.__init__(self,*args,**kwargs)
            width = 2.81
            # http://journals.pepublishing.com/index/PT68867252L15657.pdf
            # "Finally, the height of a Class 373 was reduced by. 0.75 m, from 3.334 m, in steps of 0.25 m"
            height = 3.334 
    class Cl373End(Cl373Vehicle):
        length = 21.84
        axles = 3
        coupling = (Scharfenberg, None)
        bogies = [-0.37*length, 0.5*length]
        csv = 'class373-end.csv'
    class Cl373Articulated(Cl373Vehicle):
        # weight 28.1-29.7 t
        length = 18.70
        axles = 2
        powered = 0
        coupling = (None, None)
        bogies = [-0.5*length, 0.5*length]
        csv = 'class373-art.csv'
    class DM(Cl373Vehicle):
        def __init__(self, *args,**kwargs):
            Class373.Cl373Vehicle.__init__(self, *args,**kwargs)

            self.weight = 68.5
            self.length = 22.15
            self.seats = (0, 0)
            self.axles = 4
            self.powered = 4
            self.coupling = (Scharfenberg, Scharfenberg)
            self.bogies = [-0.3*self.length, 0.35*self.length]
    class MS(Cl373End):
        weight = 44.6
        seats = (52, 0)
        powered = 2
    class TS(Cl373Articulated):
        weight = 28.9
        seats = (60, 0)
    class TBK(Cl373Articulated):
        weight = 31.1
        seats = (0, 0)
    class TF(Cl373Articulated):
        weight = 29.6
        seats = (0, 39)
    class TBF(Cl373End):
        def __init__(self, *args, **kwargs):
            Class373.Cl373End.__init__(self, *args, **kwargs)
            self.weight = 39.4
            self.seats = (0, 27)
            self.csv = 'class373-end-reflect.csv'
            self.bogies = [-0.5*self.length, 0.37*self.length]

    def __init__(self, *args):
        Consist.__init__(self, *args)
        self.coach = 'ThreeCapitals'
        self.classification = '373/1'
        self.consist = \
            (self.DM(coach='M1'),
             self.MS(coach='R1'),
             self.TS(coach='R2'),
             self.TS(coach='R3'),
             self.TS(coach='R4'),
             self.TS(coach='R5'),
             self.TBK(coach='R6'),
             self.TF(coach='R7'),
             self.TF(coach='R8'),
             self.TBF(coach='R9'),
             self.TBF(coach='R10', backwards=True),
             self.TF(coach='R11', backwards=True),
             self.TF(coach='R12', backwards=True),
             self.TBK(coach='R13', backwards=True),
             self.TS(coach='R14', backwards=True),
             self.TS(coach='R15', backwards=True),
             self.TS(coach='R16', backwards=True),
             self.TS(coach='R17', backwards=True),
             self.MS(coach='R18', backwards=True),
             self.DM(coach='M2', backwards=True))

"""
# By lowering the drag coefficient from 0.6 to 0.14 Balance to 300km / h on the train ride is about 10% less resistance.
# when a resistance when the 151.8kN was 153kN.

http://www.irail.net/webzine/y2001/m32/trend/20030416/1_7259.html
and then Google translate

Finally, the Class 373 in the height of 3.334m from 0.25m to 0.75m in
the cross-sectional area of 9m2 is reduced it from the train 7m2,
perimeter of 0.5m to 9.7m from 11.2m to stage, if you change the
height of the train as gidaedoen is reduced to approximately 10%
gongryeok resistance was reduced (Fig. 6).
"""

class Class373NoL(Class373):
    def __init__(self, *args):
        Class373.__init__(self, *args)

        self.classification = '373/2'
        self.coach = 'NorthofLondon'
        self.consist = \
            (self.DM(coach='M1'),
             self.MS(coach='R1'),
             self.TS(coach='R2'),
             self.TS(coach='R3'),
             self.TS(coach='R4'),
             self.TBK(coach='R5'),
             self.TF(coach='R6'),
             self.TBF(coach='R7'),
             self.TBF(coach='R8', backwards=True),
             self.TF(coach='R9', backwards=True),
             self.TBK(coach='R10', backwards=True),
             self.TS(coach='R11', backwards=True),
             self.TS(coach='R12', backwards=True),
             self.TS(coach='R13', backwards=True),
             self.MS(coach='R14', backwards=True),
             self.DM(coach='M2', backwards=True))

e = Class373()
f = Class373NoL()
#nol = Class373NoL()

print sum (v.length for v in e.consist)
print sum (v.length for v in f.consist)
print e, len(e)
print f, len(f)
e.dump_extensionscfg()

#print e.sub_vehicles()

